@@ -1,7 +1,7 @@
-mod command;
+/// Higher-level constructs for g-code emission
+pub mod command;
 mod format;
 mod token;
 
-pub use command::*;
 pub use format::{format_gcode_fmt, format_gcode_io, FormatOptions};
 pub use token::{Field, Token, Value};
